@@ -17,7 +17,7 @@
 #'
 #' @return a dataframe ready for the rest of the e1d scripts
 #'
-#' @importFrom dplyr mutate select filter
+#' @importFrom dplyr mutate filter
 #'
 #' @export
 #'
@@ -39,6 +39,7 @@ create_dummy_data_e1d <- function(df_type = "student") {
                                                     size = 100,
                                                     replace = TRUE),
                          StudentLevel = c(rep("Undergraduate", 40), rep("Graduate", 40), rep("Undergraduate", 20)),
+                         IsHighSchool = c(rep(0, 99), 1),
                          RaceEthnicity = 1,
                          Sex = sample(x = c(1,2),
                                       size = 100,
