@@ -15,6 +15,7 @@ library(IPEDSuploadables)
 adm_dat <- data.frame(StudentId = seq(1:24),
                       FtPt = c(rep('FT', 23), 'PT'),
                       Sex = rep(c("M", "F"), 12),
+                      GenderDetail = c(rep(c("M", "F"), 11), "U", "A"),
                       Admit = c(rep(1, 16), rep(0, 8)),
                       Enroll = c(rep(1, 12), rep(0, 12)),
                       SAT = c(rep(1, 8), rep(0, 16)),
@@ -56,25 +57,58 @@ knitr::kable(partA,
 partB <- data.frame(UNITID = 999999,
                     SURVSECT = 'ADM',
                     PART = 'B',
-                    APPLCNM = nrow(adm_dat[adm_dat$Sex == 'M', ]),
-                    APPLCNW = nrow(adm_dat[adm_dat$Sex == 'F', ]),
+                    APPLCNM = nrow(adm_dat[adm_dat$GenderDetail == 'M', ]),
+                    APPLCNW = nrow(adm_dat[adm_dat$GenderDetail == 'F', ]),
                     APPLCNT = nrow(adm_dat),
-                    ADMSSNM = nrow(adm_dat[adm_dat$Sex == 'M' & adm_dat$Admit == 1,]),
-                    ADMSSNW = nrow(adm_dat[adm_dat$Sex == 'F' & adm_dat$Admit == 1,]),
+                    ADMSSNM = nrow(adm_dat[adm_dat$GenderDetail == 'M' & 
+                                             adm_dat$Admit == 1,]),
+                    ADMSSNW = nrow(adm_dat[adm_dat$GenderDetail == 'F' & 
+                                             adm_dat$Admit == 1,]),
                     ADMSSNT = nrow(adm_dat[adm_dat$Admit == 1,]),
-                    ENRLFTM = nrow(adm_dat[adm_dat$Sex == 'M' & adm_dat$Enroll == 1 & adm_dat$FtPt == 'FT', ]),
-                    ENRLFTW = nrow(adm_dat[adm_dat$Sex == 'F' & adm_dat$Enroll == 1 & adm_dat$FtPt == 'FT', ]),
-                    ENRLFTT = nrow(adm_dat[adm_dat$Enroll == 1 & adm_dat$FtPt == 'FT', ]),
-                    ENRLPTM = nrow(adm_dat[adm_dat$Sex == 'M' & adm_dat$Enroll == 1 & adm_dat$FtPt == 'PT', ]),
-                    ENRLPTW = nrow(adm_dat[adm_dat$Sex == 'F' & adm_dat$Enroll == 1 & adm_dat$FtPt == 'PT', ]),
-                    ENRLPTT = nrow(adm_dat[adm_dat$Enroll == 1 & adm_dat$FtPt == 'PT', ]),
-                    ADMGU01 = 2, #can you report "another gender"?
-                    APPLCNAG = -2,
-                    ADMSSNAG = -2,
-                    ENRLFTAG = -2,
-                    ENRLPTAG = -2
+                    ENRLFTM = nrow(adm_dat[adm_dat$GenderDetail == 'M' & 
+                                             adm_dat$Enroll == 1 & 
+                                             adm_dat$FtPt == 'FT', ]),
+                    ENRLFTW = nrow(adm_dat[adm_dat$GenderDetail == 'F' & 
+                                             adm_dat$Enroll == 1 & 
+                                             adm_dat$FtPt == 'FT', ]),
+                    ENRLFTT = nrow(adm_dat[adm_dat$Enroll == 1 & 
+                                             adm_dat$FtPt == 'FT', ]),
+                    ENRLPTM = nrow(adm_dat[adm_dat$GenderDetail == 'M' & 
+                                             adm_dat$Enroll == 1 & 
+                                             adm_dat$FtPt == 'PT', ]),
+                    ENRLPTW = nrow(adm_dat[adm_dat$GenderDetail == 'F' & 
+                                             adm_dat$Enroll == 1 & 
+                                             adm_dat$FtPt == 'PT', ]),
+                    ENRLPTT = nrow(adm_dat[adm_dat$Enroll == 1 & 
+                                             adm_dat$FtPt == 'PT', ]),
+                    #can you report another gender? 1 = yes, 2 = no
+                    ADMGU01 = 1,
+                    #if you said 1, keep the code below as-is
+                    #if you said 2, remove code, and assign -2 to all 4 columns
+                    APPLCNAG = nrow(adm_dat[adm_dat$GenderDetail == 'A', ]),
+                    ADMSSNAG = nrow(adm_dat[adm_dat$GenderDetail == 'A' & 
+                                              adm_dat$Admit == 1, ]),
+                    ENRLFTAG = nrow(adm_dat[adm_dat$GenderDetail == 'A' & 
+                                              adm_dat$Enroll == 1 & 
+                                              adm_dat$FtPt == 'FT', ]),
+                    ENRLPTAG = nrow(adm_dat[adm_dat$GenderDetail == 'A' & 
+                                              adm_dat$Enroll == 1 & 
+                                              adm_dat$FtPt == 'PT', ])
                     )
 
+#mask data if you ARE able to report "Another Gender", 
+# but the count is below 5 in any category
+#if you are NOT able to report "Another Gender", 
+# this code will not change your data, even if you run it
+if((partB$APPLCNAG < 5 | partB$ADMSSNAG < 5 | 
+    partB$ENRLFTAG < 5 | partB$ENRLPTAG < 5) & partB$ADMGU01 == 1){
+  partB$ADMGU01 <- 3
+  partB$APPLCNAG <- -2
+  partB$ADMSSNAG <- -2
+  partB$ENRLFTAG <- -2
+  partB$ENRLPTAG <- -2
+}
+
 ## ----printB, echo=FALSE-------------------------------------------------------
 knitr::kable(partB, 
             format = 'html')
@@ -102,7 +136,27 @@ partC <- data.frame(UNITID = 999999,
                     ACTEN25 = -2,
                     ACTEN75 = -2,
                     ACTMT25 = -2,
-                    ACTMT75 = -2)
+                    ACTMT75 = -2,
+                    SATVR50 = quantile(adm_enr$SAT_V[!is.na(adm_enr$SAT_V)], .5),
+                    SATMT50 = quantile(adm_enr$SAT_M[!is.na(adm_enr$SAT_M)], .5),
+                    ACTCM50 = quantile(adm_enr$ACT_CMP[!is.na(adm_enr$ACT_CMP)], .5),
+                    ACTEN50 = -2,
+                    ACTMT50 = -2)
+
+#mask data for an exam if you have fewer than 5 students counted for it
+if(partC$SATINUM < 5){
+  partC <- partC %>%
+    mutate(across(c("SATVR25", "SATVR75", "SATVR50",
+                    "SATMT25", "SATMT75", "SATMT50"), 
+                  function(x) -2))
+}
+if(partC$ACTNUM < 5){
+  partC <- partC %>%
+    mutate(across(c("ACTCM25", "ACTCM75", "ACTCM50", 
+                    "ACTMT25", "ACTMT75", "ACTMT50", 
+                    "ACTEN25", "ACTEN75", "ACTEN50"), 
+                  function(x) -2))
+}
 
 ## ----printC, echo=FALSE-------------------------------------------------------
 knitr::kable(partC, 
